@@ -5,6 +5,8 @@ OC.L10N.register(
     "Talk" : "Paroli",
     "Guest" : "Gasto",
     "Message deleted by author" : "Mesaĝo estas forigita per aǔtoro",
+    "Administration" : "Administrado",
+    "System" : "Sistemo",
     "Talk conversations" : "Buŝaj konversacioj",
     "Talk to %s" : "Paroli al %s",
     "File is too big" : "Dosiero tro grandas",
@@ -252,38 +254,47 @@ OC.L10N.register(
     "South Africa" : "Sud-Afriko",
     "Zambia" : "Zambio",
     "Zimbabwe" : "Zimbabvo",
+    "Federation" : "Federado",
     "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
-    "Limit to groups" : "Limigi al grupoj",
     "Everyone" : "Ĉiuj",
     "Save changes" : "Konservi ŝanĝojn",
     "Saving …" : "Konservado...",
     "Saved!" : "Konservita!",
+    "Limit to groups" : "Limigi al grupoj",
+    "Disabled" : "Malŝaltita",
     "Name" : "Nomo",
     "Description" : "Priskribo",
-    "Disabled" : "Malŝaltita",
-    "Federation" : "Federado",
     "Beta" : "Beta",
-    "Language" : "Lingvo",
-    "Country" : "Lando",
-    "Status" : "Stato",
-    "Created at" : "Kreita je",
+    "Enable encryption" : "Ŝalti ĉifradon",
     "Pending" : "Pritraktota",
     "Error" : "Eraro",
     "Blocked" : "Barita",
     "Expired" : "Senvalidiĝis",
+    "Language" : "Lingvo",
+    "Country" : "Lando",
+    "Status" : "Stato",
+    "Created at" : "Kreita je",
     "OK" : "Bone",
-    "Back" : "Antaŭen",
-    "Cancel" : "Nuligi",
     "Confirm" : "Konfirmi",
     "Reset" : "Restarigi",
+    "Back" : "Antaŭen",
+    "Cancel" : "Nuligi",
+    "Loading …" : "Ŝargado...",
+    "No upcoming events" : "Neniuj venontaj eventoj",
+    "From" : "De",
+    "To" : "Al",
+    "Calendar" : "Kalendaro",
+    "Attendees" : "Ĉeestontoj",
+    "Save" : "Konservi",
+    "No results" : "Neniu rezulto",
+    "Done" : "Farita",
     "Copy link" : "Kopii ligilon",
     "You" : "Vi",
     "Collapse" : "Maletendi",
     "Favorite" : "Pliŝatata",
-    "Loading …" : "Ŝargado...",
+    "Date:" : "Dato:",
     "Hide details" : "Kaŝi la detalojn",
     "Show details" : "Montri la detalojn",
-    "Date:" : "Dato:",
     "Disable" : "Malŝalti",
     "Enable" : "Ŝalti",
     "Choose" : "Elekti",
@@ -292,22 +303,15 @@ OC.L10N.register(
     "No" : "Ne",
     "Yes" : "Jes",
     "Password protection" : "Protektita per pasvorto",
-    "Save" : "Konservi",
     "Edit" : "Modifi",
     "Delete" : "Forigi",
     "Log content" : "Protokolenhavo",
-    "User" : "Uzanto",
-    "Password" : "Pasvorto",
-    "API token" : "API-ĵetono",
-    "Login" : "Login",
-    "Nickname" : "Kromnomo",
-    "Client ID" : "Klientidentigilo",
     "Notifications" : "Sciigoj",
+    "Log in" : "Ensaluti",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
     "Users" : "Uzantoj",
     "Groups" : "Grupoj",
-    "Loading" : "Ŝargado",
     "None" : "Nenio",
     "Devices" : "Aparatoj",
     "Upload" : "Alŝuti",
@@ -319,17 +323,14 @@ OC.L10N.register(
     "Today" : "Hodiaŭ",
     "Yesterday" : "Hieraŭ",
     "_%n day ago_::_%n days ago_" : ["antaŭ %n tago","antaŭ %n tagoj"],
-    "Close" : "Malfermi",
-    "Password protect" : "Protekti per pasvorto",
-    "Group" : "Grupo",
     "Create new poll" : "Krei novan enketon",
-    "Settings" : "Agordoj",
     "Send" : "Sendi",
+    "Settings" : "Agordoj",
+    "Anonymous poll" : "Enketo sennoma",
     "Join" : "Aliĝi",
     "guest" : "gasto",
-    "Searching …" : "Serĉado ...",
-    "No results" : "Neniu rezulto",
     "Add users or groups" : "Add users or groups",
+    "Searching …" : "Serĉado ...",
     "Chat" : "Babili",
     "Details" : "Detaloj",
     "Privacy" : "Privateco",
@@ -339,14 +340,25 @@ OC.L10N.register(
     "Grid view" : "Krada vido",
     "Select a region" : "Elekti regionon",
     "Submit" : "Sendi",
+    "User" : "Uzanto",
+    "Password" : "Pasvorto",
+    "API token" : "API-ĵetono",
+    "Login" : "Login",
+    "Nickname" : "Kromnomo",
+    "Client ID" : "Klientidentigilo",
     "Polls" : "Enketilo",
     "Audio" : "Sonaĵo",
     "Other" : "Alia",
+    "Group" : "Grupo",
+    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
     "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
-    "Circles" : "Rondoj",
-    "Open sidebar" : "Malfermi flankopanelon"
+    "__language_name__" : "Esperanto",
+    "Tasks" : "Taskoj",
+    "Loading" : "Ŝargado",
+    "Close" : "Malfermi",
+    "Password protect" : "Protekti per pasvorto"
 },
 "nplurals=2; plural=(n != 1);");
