@@ -12,6 +12,8 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "Administration" : "Administración",
+    "System" : "Sistema",
     "Talk to %s" : "Hablar con %s",
     "File is too big" : "El archivo es demasiado grande.",
     "Invalid file provided" : "Archivo proporcionado inválido",
@@ -29,24 +31,25 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
-    "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
-    "Name" : "Nombre",
-    "Description" : "Descripción",
+    "Limit to groups" : "Limitar a grupos",
     "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
+    "Name" : "Nombre",
+    "Description" : "Descripción",
     "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
-    "Language" : "Idioma",
-    "Country" : "País",
-    "Status" : "Estatus",
-    "Created at" : "Creado en",
+    "Enable encryption" : "Habilitar encripción",
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
     "Expired" : "Expirado",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estatus",
+    "Created at" : "Creado en",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
@@ -55,15 +58,19 @@ OC.L10N.register(
     "Failed" : "Falló",
     "OK" : "OK",
     "Checking …" : "Verificando ...",
-    "Back" : "Atrás",
-    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Copy link" : "Copiar liga",
+    "Back" : "Atrás",
+    "Cancel" : "Cancelar",
+    "Calendar" : "Calendario",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "No hay resultados",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
@@ -80,17 +87,16 @@ OC.L10N.register(
     "Yes" : "Si",
     "Delete conversation" : "Borrar conversación",
     "Password protection" : "Protección con contraseña",
-    "Save" : "Guardar",
+    "Set a password" : "Establecer una contraseña",
     "Edit" : "Editar",
     "Delete" : "Borrar",
     "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
-    "Login" : "Iniciar sesión",
+    "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "Loading" : "Cargando",
     "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
@@ -102,20 +108,17 @@ OC.L10N.register(
     "Contact" : "Contacto",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Create new poll" : "Crear nueva encuesta",
-    "Settings" : "Configuraciones ",
-    "Create poll" : "Crear encuesta",
     "Send" : "Enviar",
+    "Create poll" : "Crear encuesta",
+    "Settings" : "Configuraciones ",
     "moderator" : "moderador",
+    "Remove participant" : "Eliminar participante",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
     "Remove" : "Remover",
-    "Remove participant" : "Eliminar participante",
-    "No results" : "No hay resultados",
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
@@ -123,8 +126,6 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -132,18 +133,22 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "User" : "Usuario",
     "Password" : "Contraseña",
     "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
     "Nickname" : "Apodo",
     "Client ID" : "ID del cliente",
     "Polls" : "Encuestas",
     "Audio" : "Audio",
     "Other" : "Otro",
     "Group" : "Grupo",
+    "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Away" : "Ausente",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
@@ -155,7 +160,11 @@ OC.L10N.register(
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
-    "Circles" : "Círculos",
+    "__language_name__" : "Español (Chile)",
+    "Tasks" : "Tareas",
+    "Loading" : "Cargando",
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
