@@ -68,6 +68,8 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
     "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
     "Message deleted by author" : "Mensaje eliminado por el autor",
+    "Administration" : "Administración",
+    "System" : "Sistema",
     "%s (guest)" : "%s (invitado)",
     "Talk conversations" : "Conversaciones de Talk",
     "Talk to %s" : "Hablar con %s",
@@ -91,9 +93,8 @@ OC.L10N.register(
     "Decline" : "Rechazar",
     "{user} sent you a private message" : "{user} te envió un mensaje privado",
     "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
-    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
-    "Join call" : "Unirse a la llamada",
     "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
+    "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "error" : "error",
@@ -319,30 +320,31 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
-    "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saving …" : "Guardando ...",
     "Saved!" : "¡Guardado!",
+    "Limit to groups" : "Limitar a grupos",
+    "Enabled" : "Habilitado",
+    "Disabled" : "Deshabilitado",
     "State" : "Estado",
     "Name" : "Nombre",
     "Description" : "Descripción",
-    "Enabled" : "Habilitado",
-    "Disabled" : "Deshabilitado",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
-    "General settings" : "Configuraciones generales",
     "@-mentions only" : "Solo menciones con @",
     "Off" : "Desactivado",
-    "Language" : "Idioma",
-    "Country" : "País",
-    "Status" : "Estatus",
-    "Created at" : "Creado en",
+    "General settings" : "Configuraciones generales",
+    "Enable encryption" : "Habilitar encripción",
     "Pending" : "Pendiente",
     "Error" : "Error",
     "Blocked" : "Bloqueado",
     "Active" : "Activo",
     "Expired" : "Expirado",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estatus",
+    "Created at" : "Creado en",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
@@ -352,15 +354,24 @@ OC.L10N.register(
     "OK" : "OK",
     "Checking …" : "Verificando ...",
     "Federated user" : "Usuario federado",
-    "Back" : "Atrás",
-    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Reiniciar",
-    "Copy link" : "Copiar liga",
+    "Back" : "Atrás",
+    "Cancel" : "Cancelar",
+    "Loading …" : "Cargando …",
+    "No upcoming events" : "No hay eventos próximos",
+    "From" : "De",
+    "To" : "Para",
+    "Calendar" : "Calendario",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "Sin resultados",
+    "Done" : "Terminado",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
@@ -369,15 +380,14 @@ OC.L10N.register(
     "Collapse" : "Colapsar",
     "Drop your files to upload" : "Arrastre sus archivos para cargar",
     "Favorite" : "Hacer favorito",
-    "Loading …" : "Cargando …",
-    "Hide details" : "Ocultar detalles",
-    "Show details" : "Mostrar detalles",
     "Date:" : "Fecha:",
     "Note:" : "Nota:",
+    "Hide details" : "Ocultar detalles",
+    "Show details" : "Mostrar detalles",
     "Disable" : "Deshabilitar",
     "Enable" : "Activar",
-    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Choose" : "Seleccionar",
+    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Restricted" : "Restringido",
     "Personal" : "Personal",
     "Meeting" : "Reunión",
@@ -386,79 +396,76 @@ OC.L10N.register(
     "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
     "_%n day_::_%n days_" : ["%n día","%n días","%n días"],
     "Password protection" : "Protección con contraseña",
-    "Save" : "Guardar",
+    "Set a password" : "Establecer una contraseña",
     "Edit" : "Editar",
     "Delete" : "Eliminar",
     "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
     "Enter your name" : "Ingrese su nombre",
-    "Login" : "Iniciar sesión",
+    "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Unread" : "No leído",
     "Clear filter" : "Limpiar filtro",
     "Unread mentions" : "Menciones sin leer",
     "Users" : " Usuarios",
     "Groups" : "Grupos",
     "Teams" : "Equipos",
     "No search results" : "No hay resultados de búsqueda",
-    "Loading" : "Cargando",
-    "Select a device" : "Seleccionar un dispositivo",
     "None" : "Ninguno",
+    "Select a device" : "Seleccionar un dispositivo",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
+    "Invalid path selected" : "Ruta seleccionada no válida.",
     "Blur" : "Difuminar",
     "Upload" : "Cargar",
     "Files" : "Archivos",
-    "Invalid path selected" : "Ruta seleccionada no válida.",
-    "Reply" : "Responder",
-    "Set reminder" : "Establecer recordatorio",
-    "Translate" : "Traducir",
     "Set reminder for later today" : "Configurar recordatorio para hoy, más tarde",
     "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
     "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
     "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
+    "Reply" : "Responder",
+    "Set reminder" : "Establecer recordatorio",
+    "Translate" : "Traducir",
     "Dismiss" : "Descartar",
     "Translate from" : "Traducir desde",
     "Contact" : "Contacto",
     "Copy code block" : "Copiar bloque de código",
-    "No messages" : "Sin mensajes",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "No messages" : "Sin mensajes",
+    "Share from Files" : "Compartir desde Archivos",
     "Upload from device" : "Cargar desde el dispositivo",
     "Create new poll" : "Crear nueva encuesta",
     "Smart picker" : "Selector inteligente",
-    "Share from Files" : "Compartir desde Archivos",
     "New file" : "Archivo nuevo",
     "Blank" : "Vacío",
-    "Settings" : "Configuraciones ",
-    "Create poll" : "Crear encuesta",
-    "Send" : "Enviar",
     "Add more files" : "Añadir más archivos",
+    "Send" : "Enviar",
+    "Create poll" : "Crear encuesta",
+    "Settings" : "Configuraciones ",
     "moderator" : "moderador",
     "guest" : "invitado",
+    "Remove participant" : "Eliminar participante",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
     "Remove" : "Borrar",
-    "Remove participant" : "Eliminar participante",
-    "Searching …" : "Buscando  …",
-    "No results" : "Sin resultados",
-    "Search for more users" : "Buscar más usuarios",
     "Add users or groups" : "Agregar usuarios o grupos",
+    "Searching …" : "Buscando  …",
+    "Search for more users" : "Buscar más usuarios",
     "Participants" : "Participantes",
     "Chat" : "Chat",
     "Details" : "Detalles",
+    "Load more results" : "Cargar más resultados",
     "Projects" : "Proyectos",
     "Edit display name" : "Editar el nombre para mostrar",
+    "Appearance" : "Apariencia",
     "Privacy" : "Privacidad",
     "Performance" : "Desempeño",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -466,6 +473,8 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Exit full screen (F)" : "Salir de pantalla completa (F)",
     "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
@@ -474,6 +483,7 @@ OC.L10N.register(
     "User" : "Usuario",
     "Password" : "Contraseña",
     "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
     "Nickname" : "Apodo",
     "Client ID" : "ID del cliente",
     "Media" : "Multimedia",
@@ -483,8 +493,10 @@ OC.L10N.register(
     "Other" : "Otro",
     "Show all files" : "Mostrar todos los archivos",
     "Group" : "Grupo",
+    "Team" : "Equipo",
     "Error while sharing file" : "Error al compartir el archivo",
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
+    "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Ausente",
     "Default" : "Predeterminado",
@@ -498,6 +510,10 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
+    "__language_name__" : "Español (México)",
+    "Tasks" : "Tareas",
+    "Notes" : "Notas",
+    "Reports" : "Informes",
     "There are currently no commands available." : "No hay comandos disponibles actualmente",
     "The command does not exist" : "El comando no existe",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
@@ -506,9 +522,11 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
-    "More unread mentions" : "Más menciones no leídas",
+    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
     "Command" : "Comando",
-    "Circles" : "Círculos",
+    "Loading" : "Cargando",
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
