@@ -22,6 +22,8 @@ OC.L10N.register(
     "{actor} created the conversation" : "{actor} membuat sebuah percakapan",
     "You created the conversation" : "Anda membuat sebuah percakapan",
     "Message deleted by author" : "Pesan dihapus oleh penyusun",
+    "Administration" : "Administrasi",
+    "System" : "Sistem",
     "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas tidak valid",
     "Invalid image" : "Gambar tidak valid",
@@ -251,36 +253,44 @@ OC.L10N.register(
     "Federation" : "Federasi",
     "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
     "Request password" : "Minta kata sandi",
-    "Limit to groups" : "Batasi ke grup",
     "Everyone" : "Semua orang",
     "Save changes" : "Simpan perubahan",
     "Saving …" : "Menyimpan ...",
+    "Limit to groups" : "Batasi ke grup",
+    "Enabled" : "Diaktifkan",
+    "Disabled" : "Dinonaktifkan",
     "State" : "Kondisi",
     "Name" : "Nama",
     "Description" : "Deskrisi",
-    "Enabled" : "Diaktifkan",
-    "Disabled" : "Dinonaktifkan",
     "Off" : "Nonaktif",
+    "Enable encryption" : "Aktifkan enkripsi",
+    "Pending" : "Tunggu",
+    "Error" : "Kesalahan",
     "Language" : "Bahasa",
     "Country" : "Negara",
     "Status" : "Status",
     "Created at" : "Dibuat saat",
-    "Pending" : "Tunggu",
-    "Error" : "Kesalahan",
     "Failed" : "Gagal",
     "OK" : "OK",
-    "Back" : "Kembali",
-    "Cancel" : "Membatalkan",
     "Confirm" : "Konfirmasi",
     "Reset" : "Setel ulang",
+    "Back" : "Kembali",
+    "Cancel" : "Membatalkan",
+    "Loading …" : "Memuat …",
+    "No upcoming events" : "Tdak ada acara mendatang",
+    "Calendar" : "Kalender",
+    "Attendees" : "Peserta",
+    "Save" : "Simpan",
+    "No results" : "Tidak ada hasil",
+    "Done" : "Selesai",
     "Copy link" : "Salin tautan",
     "Collapse" : "Tutup",
     "Expand" : "Perluas",
     "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
     "Favorite" : "Favorit",
+    "Date:" : "Tanggal:",
     "Hide details" : "Sembunyikan detail",
     "Show details" : "Tampilkan detail",
-    "Date:" : "Tanggal:",
     "Disable" : "Nonaktifkan",
     "Enable" : "Aktifkan",
     "Choose" : "Pilih",
@@ -288,11 +298,11 @@ OC.L10N.register(
     "Personal" : "Pribadi",
     "Meeting" : "Rapat",
     "Password protection" : "Password protection",
-    "Save" : "Simpan",
     "Edit" : "Sunting",
     "Delete" : "Hapus",
     "Notifications" : "Pemberitahuan",
-    "Login" : "Log masuk",
+    "Create conversation" : "Buat percakapan",
+    "Log in" : "Masuk",
     "Mark as read" : "tandai sudah dibaca",
     "Mark as unread" : "Tandai belum dibaca",
     "Remove from favorites" : "Remove from favorites",
@@ -301,11 +311,11 @@ OC.L10N.register(
     "Users" : "Pengguna",
     "Groups" : "Grup",
     "No search results" : "Tidak ada hasil pencarian",
-    "Loading" : "Memuat",
     "None" : "Tidak ada",
+    "Invalid path selected" : "Jalur terpilih invalid",
+    "Blur" : "Kabur",
     "Upload" : "Unggah",
     "Files" : "Berkas",
-    "Invalid path selected" : "Jalur terpilih invalid",
     "Unread messages" : "Pesan belum dibaca",
     "Reply" : "Balas",
     "Translate" : "Terjemahkan",
@@ -314,29 +324,27 @@ OC.L10N.register(
     "Today" : "Hari ini",
     "Yesterday" : "Kemarin",
     "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
-    "Create conversation" : "Buat percakapan",
     "Add participants" : "Tambahkan peserta",
-    "Close" : "Tutup",
     "Allow guests to join via link" : "Izinkan tamu untuk bergabung melalui tautan",
-    "Password protect" : "Lindungi dengan kata sandi",
     "New file" : "File baru",
     "Blank" : "Kosong",
-    "Settings" : "Setelan",
     "Send" : "Kirim",
+    "Settings" : "Setelan",
     "Join" : "Gabung",
     "guest" : "pengunjung",
     "Remove" : "Hapus",
-    "Integrations" : "Integrasi",
-    "No results" : "Tidak ada hasil",
     "Add users or groups" : "Add users or groups",
+    "Integrations" : "Integrasi",
     "Search or add participants" : "Cari atau tambah peserta",
     "An error occurred while adding the participants" : "Terjadi kesalahan saat menambahkan peserta",
-    "Details" : "Detail",
     "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
+    "Details" : "Detail",
+    "Load more results" : "Muat lebih banyak hasil",
     "Projects" : "Proyek",
     "Search conversations or users" : "Cari percakapan atau pengguna",
     "Choose devices" : "Pilih perangkat",
     "Attachments folder" : "Folder lampiran",
+    "Appearance" : "Tampilan",
     "Privacy" : "Privasi",
     "Performance" : "Performa",
     "Keyboard shortcuts" : "Pintasan keyboard",
@@ -347,6 +355,7 @@ OC.L10N.register(
     "User" : "Pengguna",
     "Password" : "Kata kunci",
     "API token" : "Token API",
+    "Login" : "Log masuk",
     "Nickname" : "Nama panggilan",
     "Client ID" : "ID Klien",
     "Media" : "Media",
@@ -355,11 +364,21 @@ OC.L10N.register(
     "Other" : "Lainnya",
     "Show all files" : "Tampilkan semua berkas",
     "Group" : "Grup",
+    "Please reload the page." : "Silakan muat ulang halaman.",
     "Do not disturb" : "Jangan diganggu",
     "Away" : "Jauh",
     "Default" : "Bawaan",
     "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
     "Android app" : "Aplikasi Android",
-    "iOS app" : "Aplikasi iOS"
+    "iOS app" : "Aplikasi iOS",
+    "__language_name__" : "Bahasa Indonesia",
+    "Call summary (%s)" : "Ringkasan panggilan ( %s )",
+    "Tasks" : "Tugas",
+    "Notes" : "Catatan",
+    "Reports" : "Laporan",
+    "Call summary - {title}" : "Ringkasan panggilan - {judul}",
+    "Loading" : "Memuat",
+    "Close" : "Tutup",
+    "Password protect" : "Lindungi dengan kata sandi"
 },
 "nplurals=1; plural=0;");
